@@ -1,7 +1,7 @@
 from django.db import models
 from wagtail.snippets.edit_handlers import SnippetChooserPanel
 
-from webspace.cms.bakery.abstract import WagtailPageBakeryModel
+from webspace.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.loader import get_model
 from webspace.cms.forms.abstract import FormMixin
